Thanks
------

Bidict has benefited from the assistance of many people and projects.


People
======

- Gregory Ewing for the name.

- Terry Reedy for suggesting the slice syntax
  (it was fun while it lasted).

- Raymond Hettinger for suggesting :func:`~bidict.namedbidict`,
  providing feedback on the design and implementation,
  and (most of all) for the amazing work on Python's built-in collections
  that made bidict possible.

- Francis Carr for the idea of storing the inverse bidict.

- Adopt Pytest Month 2015 for choosing bidict,
  Tom Viner for being bidict's Adopt Pytest helper for the month,
  and Brianna Laugher for coordinating.

- Daniel Pope, Leif Walsh, David Turner, and Michael Arntzenius
  for suggestions, code reviews, and design discussion.

- Leif Walsh for contributing the initial
  `devcontainer <https://code.visualstudio.com/docs/remote/containers>`__
  setup.

- Jozef Knaperek for the bugfix.

- Igor Nehoroshev for contributing the py.typed marker.

- Bernát Gábor for pyproject.toml support.

- Richard Sanger, Zeyi Wang, and Amol Sahsrabudhe for reporting bugs.


Projects
========

- `Python <https://www.python.org>`__
- `GitHub <https://github.com>`__
- `Tidelift <https://tidelift.com>`__
- `mypy <https://mypy.readthedocs.io>`__
- `Pytest <https://docs.pytest.org>`__
- `Hypothesis <https://hypothesis.readthedocs.io>`__
- `Pytest-Benchmark <https://pytest-benchmark.readthedocs.io>`__
- `Coverage <https://coverage.readthedocs.io>`__
- `Codecov <https://codecov.io>`__
- `Sphinx <https://www.sphinx-doc.org>`__
- `Readthedocs <https://readthedocs.org>`__
- `Flake8 <https://flake8.pycqa.org>`__
- `Pylint <https://www.pylint.org>`__
- `pre-commit <https://pre-commit.com>`__
